@@ -12,15 +12,22 @@ import (
 )
 
 func main() {
-	db, err := redka.Open("data.db", nil)
+	// Open the database.
+	db, err := redka.Open("redka.db", nil)
 	if err != nil {
 		log.Fatal(err)
 	}
-	defer db.Close()
+	defer func() { _ = db.Close() }()
 
+	// Set some values.
 	err = db.Str().Set("name", "alice")
 	slog.Info("set", "err", err)
+	err = db.Str().Set("age", 25)
+	slog.Info("set", "err", err)
 
-	count, err := db.Key().Count("name", "age", "city")
-	slog.Info("count", "count", count, "err", err)
+	// Read them back.
+	name, err := db.Str().Get("name")
+	slog.Info("get", "name", name, "err", err)
+	age, err := db.Str().Get("age")
+	slog.Info("get", "age", age, "err", err)
 }
